<div align="center">
  <h1>Commitizen Espressif style plugin </h1>
    Commitizen tools plugin with Espressif code style
  <br>
  <br>

[![Release][release-badge]][release-url] [![Pre-commit][pre-commit-badge]][pre-commit-url] [![Conventional Commits][conventional-badge]][conventional-url]

</div>
<hr>

- [Introduction](#introduction)
- [Contributing](#contributing)
- [License](#license)

## Introduction

TODO: Plugin commitizen

---

## Contributing

We welcome contributions from the community! Please read the [Contributing Guide](CONTRIBUTING.md) to learn how to get involved.

## License

This repository is licensed under the [Apache 2.0 License](LICENSE).

---

<!-- GitHub Badges -->

[conventional-badge]: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg?style=flat-square
[conventional-url]: https://conventionalcommits.org
[pre-commit-badge]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?style=flat-square&logo=pre-commit&logoColor=white
[pre-commit-url]: https://github.com/pre-commit/pre-commit
[release-badge]: https://img.shields.io/github/v/release/espressif/standards
[release-url]: https://github.com/espressif/standards/releases
